#!/usr/bin/env node

//native
const { existsSync } = require('fs')
const { homedir } = require('os')
const { basename, resolve } = require('path')

//third-party
const program = require('commander')

//app code
const { startServer } = require('./server')

program.version('1.0.0')

program
  .command('start <database>')
  .description(
    'Starts a restful api using the database specified. The databases are stored in ~/.parrot'
  )
  .option('-p, --port [port]', 'The port the server should listen on', 3000)
  .action(function(database, options) {
    const databasePath = database.endsWith('.json')
      ? database
      : `${database}.json`
    const relativeDatabasePath = resolve(databasePath)
    const globalDatabasePath = resolve(homedir(), '.parrot', databasePath)
    const { port } = options

    if (existsSync(relativeDatabasePath)) {
      startServer(relativeDatabasePath, port)
    } else if (existsSync(globalDatabasePath)) {
      startServer(globalDatabasePath, port)
    } else {
      console.error('database name not found')
    }
  })

program.command('*').action(function() {
  console.error('You must enter a command')
})

program.parse(process.argv)
