const jsonServer = require('json-server')
const columnify = require('columnify')

module.exports = {
  startServer(databasePath, port) {
    const requests = []
    const server = jsonServer.create()
    const router = jsonServer.router(databasePath)
    const middlewares = jsonServer.defaults({ logger: false })
    const COLUMN_SETTINGS = {
      minWidth: 10,
      config: {
        body: { maxWidth: 30 }
      }
    }
    server.use(middlewares)
    server.use((req, res, next) => {
      const stats = {
        time: Date.now(),
        method: req.method,
        path: req.path,
        status: res.statusCode
      }
      res.on('finish', () => {
        stats.body = JSON.stringify(req.body)
        requests.push(stats)
        console.clear()
        console.log(columnify(requests, COLUMN_SETTINGS))
      })

      next()
    })
    server.use(router)
    server.listen(port, () => {
      console.log(`Parrot running server on port ${port}...`)
    })
  }
}
